/*
Copyright (c) 2013, Frank Roberts 
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
    * Neither the name of the author nor the names of its contributors may 
		be used to endorse or promote products derived from this software 
		without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
ARE DISCLAIMED. IN NO EVENT SHALL FRANK ROBERTS BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF 
THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

/*
An example for how to use CCSVLIB. This example program uses every API call
and at least once.
*/
#include <stdio.h>
#include "csv.h"

int main(int argc, char **argv)
{
	if (argc != 3)
	{
		fprintf(stderr, "Usage: %s <input file> <output file>\n", argv[0]);
		exit(1);
	}

	csvtab mytab = DEFAULT_TAB(); /* expends to newTab(',', '"', '\n') */

	FILE *fin = fopen(argv[1], "r");
	if (fin == NULL)
	{
		fprintf(stderr, "Could not open %s for reading.\n", argv[1]);
		exit(2);
	}

	/* Read a CSV file into memory */
	readTab(mytab, fin);
	fclose(fin);

	/* Print out every cell, labeled with cell coordinates. */
	int i, j;
	for (i = 0; i < ROWS(mytab); i++)
	{
		for (j = 0; j < COLS(mytab); j++)
		{
			printf("Cell (%d:%d): %s\n", i, j, getContent(mytab, i, j));
		}
	}

	/* Add a cell at (6,8) that contains "Hello, World". */
	setCell(mytab, "Hello, World", 6, 8);

	/* Change field delimiter to a tab character, keep others the same */
	setDelims(mytab, '\t', ESCAPE(mytab), NEWLINE(mytab));

	FILE *fout = fopen(argv[2], "w");
	if (fout == NULL)
	{
		fprintf(stderr, "Could not open %s for writing.\n", argv[2]);
		exit(3);
	}
	/* Write out a tab delimited file */
	writeTab(mytab, fout);
	fclose(fout);

	/* Free our tab structure */
	freeTab(mytab);
	return 0;
}
